Documentation
¶
Index ¶
- func CheckFields(mapstring map[string]string, reqfields []string) (bool, error)
- func DispatcherAdd(groupval string, addressval string, urlval string) (string, error)
- func DispatcherList(urlval string) (string, error)
- func DispatcherListByGroup(urlval string) (string, error)
- func DispatcherListSimple(urlval string) (string, error)
- func DispatcherRemove(groupval string, addressval string, urlval string) (string, error)
- func HtableDelete(tableval string, keyval string, urlval string) (bool, error)
- func HtableDump(tableval string, urlval string) (string, error)
- func HtableFlush(tableval string, urlval string) (bool, error)
- func HtableGet(tableval string, keyval string, urlval string) (string, error)
- func HtableParseNameOnly(jsonval string) (string, error)
- func HtableParseNameValue(jsonval string) (string, error)
- func HtableParseValueOnly(jsonval string) (string, error)
- func HtableParseValueSingle(jsonval string) (string, error)
- func HtableSetInt(tableval string, keyval string, valval string, urlval string) (bool, error)
- func HtableSetString(tableval string, keyval string, valval string, urlval string) (bool, error)
- func RegAorParse(jsonval string) (string, error)
- func RegDeleteAOR(aorval string, urlval string) (bool, error)
- func RegGetAOR(aorval string, urlval string) (string, error)
- func RegsAors(jsonval string) (string, error)
- func RegsFullContactInfo(jsonval string) (string, error)
- func RegsGet(urlval string) (string, error)
- func RegsSimpleParse(jsonval string) (string, error)
- func RegsTotal(jsonval string) (string, error)
- func RemoveDuplicatesUnordered(elements []string) []string
- func SendGethttp(urlstr string) (string, error)
- func SendGethttpIgnoreCert(urlstr string) (string, error)
- func SendGethttpIgnoreCertTimeout(urlstr string, seconds time.Duration) (string, error)
- func SendJsonhttp(jsonstr string, urlstr string) (string, error)
- func SendJsonhttpIgnoreCert(jsonstr string, urlstr string) (string, error)
- func SendJsonhttpIgnoreCertTimeout(jsonstr string, urlstr string, seconds time.Duration) (string, error)
- func SendJsonhttpTimeout(jsonstr string, urlstr string, seconds time.Duration) (string, error)
- func Uptime(urlval string) (string, error)
- func UptimeParse(jsonval string) (string, error)
- func Version(urlval string) (string, error)
- func VersionParse(jsonval string) (string, error)
- type StructAoRParse
- type StructHtableDump
- type StructName
- type StructNameValue
- type StructUserDump
- type StructValue
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DispatcherAdd ¶
func DispatcherList ¶
func DispatcherListByGroup ¶
func DispatcherListSimple ¶
func DispatcherRemove ¶
func HtableParseNameOnly ¶
func HtableParseNameValue ¶
func HtableParseValueOnly ¶
func HtableParseValueSingle ¶
func HtableSetInt ¶
changed 2023-01-18 to treat string as int in json for seti.
func HtableSetString ¶
func RegAorParse ¶
func RegsFullContactInfo ¶
func RegsSimpleParse ¶
func SendGethttp ¶
send a get request via http and return the response
func SendGethttpIgnoreCert ¶
func SendJsonhttpIgnoreCert ¶
func SendJsonhttpTimeout ¶
func UptimeParse ¶
func VersionParse ¶
Types ¶
type StructAoRParse ¶
type StructAoRParse struct {
AoR json.RawMessage `json:"aor"`
Address json.RawMessage `json:"address"`
Expires json.RawMessage `json:"expires"`
UA json.RawMessage `json:"user-agent"`
LastModified string `json:"last-modified"`
}
type StructHtableDump ¶
type StructHtableDump struct {
Jsonrpc string `json:"jsonrpc"`
Id json.RawMessage `json:"id"`
Result []struct {
Entry any `json:"entry"`
Size any `json:"size"`
Slot []struct {
Name json.RawMessage `json:"name"`
Value json.RawMessage `json:"value"`
Type string `json:"type"`
} `json:"slot"`
} `json:"result"`
}
type StructName ¶
type StructName struct {
Name json.RawMessage `json:"name"`
}
type StructNameValue ¶
type StructNameValue struct {
Name json.RawMessage `json:"name"`
Value json.RawMessage `json:"value"`
}
type StructUserDump ¶
type StructUserDump struct {
Jsonrpc json.RawMessage `json:"jsonrpc"`
Id json.RawMessage `json:"id"`
Result struct {
Domains []struct {
Domain struct {
Domain json.RawMessage `json:"Domain"`
Size json.RawMessage `json:"Size"`
AoRs []struct {
Info struct {
AoR json.RawMessage `json:"AoR"`
HashID json.RawMessage `json:"HashID"`
Contacts []struct {
Contact struct {
Address json.RawMessage `json:"Address,omitempty"`
Expires json.RawMessage `json:"Expires,omitempty"`
Q json.RawMessage `json:"Q,omitempty"`
CallID json.RawMessage `json:"Call-ID,omitempty"`
CSeq json.RawMessage `json:"CSeq,omitempty"`
UserAgent json.RawMessage `json:"User-Agent,omitempty"`
Received json.RawMessage `json:"Received,omitempty"`
Path json.RawMessage `json:"Path,omitempty"`
Socket json.RawMessage `json:"Socket,omitempty"`
Methods json.RawMessage `json:"Methods,omitempty"`
Ruid json.RawMessage `json:"Ruid,omitempty"`
Instance json.RawMessage `json:"Instance,omitempty"`
RegID json.RawMessage `json:"Reg-Id,omitempty"`
ServerID json.RawMessage `json:"Server-Id,omitempty"`
TcpconID json.RawMessage `json:"Tcpconn-Id,omitempty"`
Keepalive json.RawMessage `json:"Keepalive,omitempty"`
LastKeepAlive json.RawMessage `json:"Last-Keepalive,omitempty"`
KARoundtrip json.RawMessage `json:"KA-Roundtrip,omitempty"`
LastModified json.RawMessage `json:"Last-Modified,omitempty"`
} `json:"Contact"`
} `json:"Contacts"`
} `json:"Info"`
} `json:"AoRs"`
Stats struct {
Records json.RawMessage `json:"Records"`
MaxSlots json.RawMessage `json:"Max-Slots"`
} `json:"Stats"`
} `json:"Domain"`
} `json:"Domains"`
} `json:"result"`
}
type StructValue ¶
type StructValue struct {
Value json.RawMessage `json:"value"`
}
Click to show internal directories.
Click to hide internal directories.